pub struct LocalClient { /* private fields */ }Expand description
Client that loops back requests to a module in this process.
Implementations
Sourceimpl LocalClient
impl LocalClient
Sourcepub fn new(modname: impl Into<String>) -> Option<Self>
pub fn new(modname: impl Into<String>) -> Option<Self>
Return a new local client connecting to the given module. None is returned if no local server is running.
pub fn ping(&self) -> Result<()>
pub fn read(&self, param: &str) -> Result<Value>
pub fn change(&self, param: &str, value: Value) -> Result<Value>
pub fn command(&self, cmd: &str, arg: Value) -> Result<Value>