This module contains the definition of a protocol message, along with tools to parse and string-format it.
Structs
- Incoming
Msg - An incoming message that carries around the originating line from the client. We need this line for the error message if something goes wrong.
Enums
- Msg
- Enum that represents any message that can be sent over the network in the protocol, and some others that are only used internally.