pub enum Msg {
Show 19 variants
Idn,
IdnReply {
encoded: String,
},
Describe,
Describing {
id: String,
structure: Value,
},
Activate {
module: String,
},
Active {
module: String,
},
Deactivate {
module: String,
},
Inactive {
module: String,
},
Do {
module: String,
command: String,
arg: Value,
},
Done {
module: String,
command: String,
data: Value,
},
Change {
module: String,
param: String,
value: Value,
},
Changed {
module: String,
param: String,
data: Value,
},
Read {
module: String,
param: String,
},
Ping {
token: String,
},
Pong {
token: String,
data: Value,
},
ErrMsg {
class: String,
report: Value,
},
Update {
module: String,
param: String,
data: Value,
},
InitUpdates {
module: String,
updates: Vec<Msg>,
},
Quit,
}Expand description
Enum that represents any message that can be sent over the network in the protocol, and some others that are only used internally.
Variants
Idn
identify request
IdnReply
identify reply
Describe
description request
Describing
description reply
Activate
event enable request
Active
event enable reply
Deactivate
event disable request
Inactive
event disable reply
Do
command execution request
Done
command result
Change
change request
Changed
change result
Read
read request
Ping
heartbeat request
Pong
heartbeat reply
ErrMsg
error reply
Update
update event
InitUpdates
not a protocol message, but a collection of initial updates
Quit
not a protocol message, indicates the connection is done
Implementations