pub struct IncomingMsg(pub String, pub Msg);Expand description
An incoming message that carries around the originating line from the client. We need this line for the error message if something goes wrong.
Tuple Fields
0: String1: MsgImplementations