Module server

Module server 

This module contains the server instance itself, and associated objects to handle connections and message routing.

Structs

Handler
The Handler represents a single client connection, both the read and write halves.
Server

Constants

MAX_MSG_LEN
RECVBUF_LEN

Statics

CON_SENDER
Global sender for new connections to the server.
REQ_SENDER
Global sender for new requests to the dispatcher.

Functions

next_handler_id

Type Aliases

ConReceiver
ConSender
HandlerId
Handler ID. This is nonzero so that Option is the same size.
ModRepReceiver
ModRepSender
RepReceiver
RepSender
ReqReceiver
ReqSender