Handler

Struct Handler 

pub struct Handler { /* private fields */ }
The Handler represents a single client connection, both the read and write halves.

The write half is in its own thread to be able to send back replies (which can come both from the Handler and the Dispatcher) instantly.

Implementations

Source

impl Handler

pub fn new( hid: HandlerId, client: TcpStream, addr: SocketAddr, req_sender: ReqSender, rep_sender: RepSender, rep_receiver: RepReceiver, ) -> Handler

pub fn handle(self)

Handle incoming stream of messages.