pub struct Handler { /* private fields */ }Expand description
The Handler represents a single client connection, both the read and write halves.
The write half is in its own thread to be able to send back replies (which can come both from the Handler and the Dispatcher) instantly.
Implementations